==> cyphesis-snapshot-1999.01.15.tar.gz: cyphesis/engine.py <==
""" engine.py
 Copyright (C) 1998 Aloril
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
"""

import sys
from types import *
from copy import copy
import defworld
from event import *
import worldi, worldi__skel
from world import world

class engine(worldi__skel.engine):
    def __init__ (self):
        self.w=world()
    def event(self, e_str):
        #print e_str,
        e=eval(e_str)
        #print self.w.time,e.command
        res=None
        if e.command=="load":
            if e.what=="default":
                self.w.destroy()
                self.w=defworld.default(e.loc=="debug")
                res=self.w.events
        elif e.command=="step":
            res=self.w.run_step()
        elif e.command=="look":
            if e.what=="all":
                res=self.w.look_all()
        if res==None:
            res=self.w.analyse_event(e)
            if res==None: res=[]
        result=[]
        for e in res:
            e=self.process_make(e)
            if e.command=="sight":
                e=copy(e)
                e.what=self.process_make(e.what)
            result.append(e)
        return `result`
        #print e_str
        #return e_str
    def process_make(self,e):
        t=e.what
        if e.command=="make" and type(t)==InstanceType:
            e=copy(e)
            e.what=ething(t.id,name=t.name,type=t.get_type())
            if not e.loc: e.loc=t.get_loc()
        return e

class factory (worldi__skel.factory):
    # have the __init__ method take handle and server args
    # so that we can control which ILU kernel server is used,
    # and what the instance handle of the Factory object on
    # that server is.  This allows us to control the object ID
    # of the new Factory instance.
    
    def __init__(self, handle=None, server=None):
        self.IluInstHandle = handle
        self.IluServer = server
    def createEngine (self):
        return engine()

==> cyphesis-snapshot-1999.02.13.tar.gz: cyphesis/engine.py <==
""" engine.py
 Copyright (C) 1998 Aloril
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
"""

import sys
from types import *
from copy import copy
from event import *
import worldi, worldi__skel
from world import world
from ibody import ibody

class engine(worldi__skel.engine):
    # have the __init__ method take handle and server args
    # so that we can control which ILU kernel server is used,
    # and what the instance handle of the Factory object on
    # that server is.  This allows us to control the object ID
    # of the new Factory instance.
    def __init__ (self, handle=None, server=None):
        self.IluInstHandle = handle
        self.IluServer = server
        self.w=world()
        self.w.analyse_event(event('debug',what='on'))
    def createBody(self, e_str):
        #print ">>",e_str
        e=eval(e_str)
        res=self.w.new_events(e)
        id=res[0].what.what.id
        body=self.w.id_dict[id]
        body.mind=ibody(name=id)
        body.mind.w=self.w
        return body.mind
    def metaEvent(self, e_str):
        #print e_str,
        e=eval(e_str)
        #print self.w.time,e.command
        res=None
        if e.command=="step":
            res=self.w.run_step()
##         elif e.command=="load":
##             if e.what=="default":
##                 self.w.destroy()
##                 self.w=defworld.default(e.loc=="debug")
##                 res=self.w.events
##         elif e.command=="login":
##             res=self.w.get_client_id()
##             print "engine.get_client_id:",res
##         elif e.command=="look":
##             if e.what=="all":
##                 res=self.w.look_all()
        if res==None: res=[]
        return `res`
